aboutsummaryrefslogtreecommitdiffstats
path: root/epan/packet_info.h
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-10-18 21:40:13 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-10-18 21:40:13 +0000
commit5d9c760a1f8a2e1ddaf43650ce7df3cb317e7ec0 (patch)
tree1d0161764112eb5c454d950fe062411f7edb6734 /epan/packet_info.h
parenteaee39ac7d604416de4189b01aef80fd75a2ab93 (diff)
Add an AT_ARCNET address type for ARCNET addresses, and have the ARCNET
dissector set the source and destination link-layer addresses. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@6452 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/packet_info.h')
-rw-r--r--epan/packet_info.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/epan/packet_info.h b/epan/packet_info.h
index 2c44165b0d..277560a563 100644
--- a/epan/packet_info.h
+++ b/epan/packet_info.h
@@ -1,7 +1,7 @@
/* packet_info.h
* Definitions for packet info structures and routines
*
- * $Id: packet_info.h,v 1.20 2002/10/15 04:31:00 guy Exp $
+ * $Id: packet_info.h,v 1.21 2002/10/18 21:40:13 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -39,7 +39,8 @@ typedef enum {
AT_ATALK, /* Appletalk DDP */
AT_VINES, /* Banyan Vines */
AT_OSI, /* OSI NSAP */
- AT_DLCI /* Frame Relay DLCI */
+ AT_DLCI, /* Frame Relay DLCI */
+ AT_ARCNET /* ARCNET */
} address_type;
typedef struct _address {